@@ -1,5 +1,6 @@
 import fnmatch
 import glob
+import inspect
 import logging
 import os
 import os.path
@@ -9,7 +10,6 @@ import re
 import sqlite3
 import subprocess
 import sys
-import tempfile
 import unicodedata
 import urllib.parse
 from plistlib import load as plistload
@@ -19,7 +19,6 @@ import CoreServices
 import objc
 
 from ._constants import UNICODE_FORMAT
-from .fileutil import FileUtil
 
 _DEBUG = False
 
@@ -62,9 +61,17 @@ def noop(*args, **kwargs):
     pass
 
 
+def lineno(filename):
+    """ Returns string with filename and current line number in caller as '(filename): line_num'
+    Will trim filename to just the name, dropping path, if any. """
+    line = inspect.currentframe().f_back.f_lineno
+    filename = pathlib.Path(filename).name
+    return f"{filename}: {line}"
+
+
 def _get_os_version():
-    # returns tuple containing OS version
-    # e.g. 10.13.6 = (10, 13, 6)
+    # returns tuple of str containing OS version
+    # e.g. 10.13.6 = ("10", "13", "6")
     version = platform.mac_ver()[0].split(".")
     if len(version) == 2:
         (ver, major) = version
@@ -260,10 +267,10 @@ def get_preferred_uti_extension(uti):
         returns: preferred extension as str """
 
     # reference: https://developer.apple.com/documentation/coreservices/1442744-uttypecopypreferredtagwithclass?language=objc
-
-    return CoreServices.UTTypeCopyPreferredTagWithClass(
-        uti, CoreServices.kUTTagClassFilenameExtension
-    )
+    with objc.autorelease_pool():
+        return CoreServices.UTTypeCopyPreferredTagWithClass(
+            uti, CoreServices.kUTTagClassFilenameExtension
+        )
 
 
 def findfiles(pattern, path_):
